@@ -94,6 +94,8 @@ def format_location(location: Region) -> dict[str, Any]:
         **location,
     }
     del data['name']
+    if not data.get('description'):
+        data.pop('description', None)
     return data
 
 
